"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing_extensions import TypedDict

from friendli.types import BaseModel


class ToolStatusParameterTypedDict(TypedDict):
    name: str
    r"""The name of the tool's function parameter."""
    value: str
    r"""The value of the tool's function parameter."""


class ToolStatusParameter(BaseModel):
    name: str
    r"""The name of the tool's function parameter."""

    value: str
    r"""The value of the tool's function parameter."""
