"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Union

from typing_extensions import TypeAliasType

from .completionsstreamdedicatedmodelbodywithprompt import (
    CompletionsStreamDedicatedModelBodyWithPrompt,
    CompletionsStreamDedicatedModelBodyWithPromptTypedDict,
)
from .completionsstreamdedicatedmodelbodywithtokens import (
    CompletionsStreamDedicatedModelBodyWithTokens,
    CompletionsStreamDedicatedModelBodyWithTokensTypedDict,
)

DedicatedCompletionsStreamBodyTypedDict = TypeAliasType(
    "DedicatedCompletionsStreamBodyTypedDict",
    Union[
        CompletionsStreamDedicatedModelBodyWithPromptTypedDict,
        CompletionsStreamDedicatedModelBodyWithTokensTypedDict,
    ],
)


DedicatedCompletionsStreamBody = TypeAliasType(
    "DedicatedCompletionsStreamBody",
    Union[
        CompletionsStreamDedicatedModelBodyWithPrompt,
        CompletionsStreamDedicatedModelBodyWithTokens,
    ],
)
