"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing_extensions import TypedDict

from friendli.types import BaseModel


class AssistantMessageToolCallFunctionTypedDict(TypedDict):
    arguments: str
    r"""The arguments of function in JSON schema format to call the function."""
    name: str
    r"""The name of function"""


class AssistantMessageToolCallFunction(BaseModel):
    arguments: str
    r"""The arguments of function in JSON schema format to call the function."""

    name: str
    r"""The name of function"""
