"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing_extensions import TypedDict

from friendli.types import BaseModel


class ToolStatusErrorTypedDict(TypedDict):
    msg: str
    r"""The message of error."""
    type: str
    r"""The type of error encountered during the tool's execution."""


class ToolStatusError(BaseModel):
    msg: str
    r"""The message of error."""

    type: str
    r"""The type of error encountered during the tool's execution."""
