"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing_extensions import TypedDict

from friendli.types import BaseModel

from .streamedchatdata import StreamedChatData, StreamedChatDataTypedDict


class ContainerChatCompletionStreamSuccessTypedDict(TypedDict):
    data: StreamedChatDataTypedDict


class ContainerChatCompletionStreamSuccess(BaseModel):
    data: StreamedChatData
