"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import List, Literal

import pydantic
from pydantic.functional_validators import AfterValidator
from typing_extensions import Annotated, TypedDict

from friendli.types import BaseModel
from friendli.utils import validate_const


class FileBuiltInToolTypedDict(TypedDict):
    files: List[str]
    r"""A List of file IDs. For now, only one file is supported."""
    type: Literal["file:text"]
    r"""The type of the file parser tool. Only .txt and .pdf files are supported."""


class FileBuiltInTool(BaseModel):
    files: List[str]
    r"""A List of file IDs. For now, only one file is supported."""

    TYPE: Annotated[
        Annotated[Literal["file:text"], AfterValidator(validate_const("file:text"))],
        pydantic.Field(alias="type"),
    ] = "file:text"
    r"""The type of the file parser tool. Only .txt and .pdf files are supported."""
