"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing_extensions import TypedDict

from friendli.types import BaseModel


class PricingModelTypedDict(TypedDict):
    r"""Price per 1M tokens in USD currency."""

    input: float
    r"""Price per input token"""
    output: float
    r"""Price per output token"""


class PricingModel(BaseModel):
    r"""Price per 1M tokens in USD currency."""

    input: float
    r"""Price per input token"""

    output: float
    r"""Price per output token"""
