"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing_extensions import TypedDict

from friendli.types import BaseModel


class ServerlessTokenizationBodyTypedDict(TypedDict):
    model: str
    r"""Code of the model to use. See [available model list](https://friendli.ai/docs/guides/serverless_endpoints/pricing#text-generation-models)."""
    prompt: str
    r"""Input text prompt to tokenize."""


class ServerlessTokenizationBody(BaseModel):
    model: str
    r"""Code of the model to use. See [available model list](https://friendli.ai/docs/guides/serverless_endpoints/pricing#text-generation-models)."""

    prompt: str
    r"""Input text prompt to tokenize."""
