"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Union

from typing_extensions import TypeAliasType

from .completionsstreamserverlessmodelbodywithprompt import (
    CompletionsStreamServerlessModelBodyWithPrompt,
    CompletionsStreamServerlessModelBodyWithPromptTypedDict,
)
from .completionsstreamserverlessmodelbodywithtokens import (
    CompletionsStreamServerlessModelBodyWithTokens,
    CompletionsStreamServerlessModelBodyWithTokensTypedDict,
)

ServerlessCompletionsStreamBodyTypedDict = TypeAliasType(
    "ServerlessCompletionsStreamBodyTypedDict",
    Union[
        CompletionsStreamServerlessModelBodyWithPromptTypedDict,
        CompletionsStreamServerlessModelBodyWithTokensTypedDict,
    ],
)


ServerlessCompletionsStreamBody = TypeAliasType(
    "ServerlessCompletionsStreamBody",
    Union[
        CompletionsStreamServerlessModelBodyWithPrompt,
        CompletionsStreamServerlessModelBodyWithTokens,
    ],
)
