"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing_extensions import TypedDict

from friendli.types import BaseModel


class VideoDataTypedDict(TypedDict):
    url: str
    r"""The URL of the video."""


class VideoData(BaseModel):
    url: str
    r"""The URL of the video."""
