"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Union

from typing_extensions import TypeAliasType

from .completionsserverlessmodelbodywithprompt import (
    CompletionsServerlessModelBodyWithPrompt,
    CompletionsServerlessModelBodyWithPromptTypedDict,
)
from .completionsserverlessmodelbodywithtokens import (
    CompletionsServerlessModelBodyWithTokens,
    CompletionsServerlessModelBodyWithTokensTypedDict,
)

ServerlessCompletionsBodyTypedDict = TypeAliasType(
    "ServerlessCompletionsBodyTypedDict",
    Union[
        CompletionsServerlessModelBodyWithPromptTypedDict,
        CompletionsServerlessModelBodyWithTokensTypedDict,
    ],
)


ServerlessCompletionsBody = TypeAliasType(
    "ServerlessCompletionsBody",
    Union[
        CompletionsServerlessModelBodyWithPrompt,
        CompletionsServerlessModelBodyWithTokens,
    ],
)
