"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

from typing_extensions import TypedDict

from friendli.types import BaseModel

B64ImageItemResponseFormat = Literal["url", "raw", "png", "jpeg", "jpg"]
r"""The format of the generated image. One of `url(default)`, `raw`, `png`, `jpeg`, and `jpg`."""


class B64ImageItemTypedDict(TypedDict):
    b64_json: bytes
    r"""The base64-encoded JSON of the generated image."""
    response_format: B64ImageItemResponseFormat
    r"""The format of the generated image. One of `url(default)`, `raw`, `png`, `jpeg`, and `jpg`."""
    seed: int
    r"""The seed used during image generation."""


class B64ImageItem(BaseModel):
    b64_json: bytes
    r"""The base64-encoded JSON of the generated image."""

    response_format: B64ImageItemResponseFormat
    r"""The format of the generated image. One of `url(default)`, `raw`, `png`, `jpeg`, and `jpg`."""

    seed: int
    r"""The seed used during image generation."""
