"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

from typing_extensions import TypedDict

from friendli.types import BaseModel

Type = Literal[
    "math:calculator",
    "math:statistics",
    "math:calendar",
    "web:search",
    "web:url",
    "code:python-interpreter",
]
r"""The type of the built-in tool."""


class OtherBuiltInToolTypedDict(TypedDict):
    type: Type
    r"""The type of the built-in tool."""


class OtherBuiltInTool(BaseModel):
    type: Type
    r"""The type of the built-in tool."""
