"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

import pydantic
from pydantic.functional_validators import AfterValidator
from typing_extensions import Annotated, TypedDict

from friendli.types import BaseModel
from friendli.utils import validate_const

from .function import Function, FunctionTypedDict


class ToolTypedDict(TypedDict):
    function: FunctionTypedDict
    type: Literal["function"]
    r"""The type of the tool. Currently, only `function` is supported."""


class Tool(BaseModel):
    function: Function

    TYPE: Annotated[
        Annotated[Literal["function"], AfterValidator(validate_const("function"))],
        pydantic.Field(alias="type"),
    ] = "function"
    r"""The type of the tool. Currently, only `function` is supported."""
