"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Union

from typing_extensions import TypeAliasType

from .completionsdedicatedmodelbodywithprompt import (
    CompletionsDedicatedModelBodyWithPrompt,
    CompletionsDedicatedModelBodyWithPromptTypedDict,
)
from .completionsdedicatedmodelbodywithtokens import (
    CompletionsDedicatedModelBodyWithTokens,
    CompletionsDedicatedModelBodyWithTokensTypedDict,
)

DedicatedCompletionsBodyTypedDict = TypeAliasType(
    "DedicatedCompletionsBodyTypedDict",
    Union[
        CompletionsDedicatedModelBodyWithPromptTypedDict,
        CompletionsDedicatedModelBodyWithTokensTypedDict,
    ],
)


DedicatedCompletionsBody = TypeAliasType(
    "DedicatedCompletionsBody",
    Union[
        CompletionsDedicatedModelBodyWithPrompt, CompletionsDedicatedModelBodyWithTokens
    ],
)
