"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import List

from typing_extensions import TypedDict

from friendli.types import BaseModel

from .modelcatalogresponseitem import (
    ModelCatalogResponseItem,
    ModelCatalogResponseItemTypedDict,
)


class ServerlessModelListSuccessTypedDict(TypedDict):
    r"""`/models` API response (for OpenRouters)."""

    data: List[ModelCatalogResponseItemTypedDict]


class ServerlessModelListSuccess(BaseModel):
    r"""`/models` API response (for OpenRouters)."""

    data: List[ModelCatalogResponseItem]
