"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing_extensions import TypedDict

from friendli.types import BaseModel


class ChatUsageTypedDict(TypedDict):
    completion_tokens: int
    r"""Number of tokens in the generated chat completions."""
    prompt_tokens: int
    r"""Number of tokens in the prompt."""
    total_tokens: int
    r"""Total number of tokens used in the request (`prompt_tokens` + `completion_tokens`)."""


class ChatUsage(BaseModel):
    completion_tokens: int
    r"""Number of tokens in the generated chat completions."""

    prompt_tokens: int
    r"""Number of tokens in the prompt."""

    total_tokens: int
    r"""Total number of tokens used in the request (`prompt_tokens` + `completion_tokens`)."""
