"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import List

from typing_extensions import TypedDict

from friendli.types import BaseModel

from .knowledgeretrievedchunk import (
    KnowledgeRetrievedChunk,
    KnowledgeRetrievedChunkTypedDict,
)


class ServerlessKnowledgeRetrievalSuccessTypedDict(TypedDict):
    r"""Knowledge retrieval response."""

    results: List[KnowledgeRetrievedChunkTypedDict]
    r"""A list of result."""


class ServerlessKnowledgeRetrievalSuccess(BaseModel):
    r"""Knowledge retrieval response."""

    results: List[KnowledgeRetrievedChunk]
    r"""A list of result."""
