"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Union

from typing_extensions import TypeAliasType

from .completionsbodywithprompt import (
    CompletionsBodyWithPrompt,
    CompletionsBodyWithPromptTypedDict,
)
from .completionsbodywithtokens import (
    CompletionsBodyWithTokens,
    CompletionsBodyWithTokensTypedDict,
)

ContainerCompletionsBodyTypedDict = TypeAliasType(
    "ContainerCompletionsBodyTypedDict",
    Union[CompletionsBodyWithPromptTypedDict, CompletionsBodyWithTokensTypedDict],
)


ContainerCompletionsBody = TypeAliasType(
    "ContainerCompletionsBody",
    Union[CompletionsBodyWithPrompt, CompletionsBodyWithTokens],
)
