"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Union

from typing_extensions import TypeAliasType

from .streamedtoolassistedchattoken import (
    StreamedToolAssistedChatToken,
    StreamedToolAssistedChatTokenTypedDict,
)
from .streamedtoolassistedchattoolstatus import (
    StreamedToolAssistedChatToolStatus,
    StreamedToolAssistedChatToolStatusTypedDict,
)

ServerlessToolAssistedChatCompletionStreamSuccessTypedDict = TypeAliasType(
    "ServerlessToolAssistedChatCompletionStreamSuccessTypedDict",
    Union[
        StreamedToolAssistedChatTokenTypedDict,
        StreamedToolAssistedChatToolStatusTypedDict,
    ],
)
r"""A server-sent event containing chat completions content."""


ServerlessToolAssistedChatCompletionStreamSuccess = TypeAliasType(
    "ServerlessToolAssistedChatCompletionStreamSuccess",
    Union[StreamedToolAssistedChatToken, StreamedToolAssistedChatToolStatus],
)
r"""A server-sent event containing chat completions content."""
